@@ -43,7 +43,7 @@ void Dailymotion::setBusy(bool isBusy, const QString &message, int numberOfOpera
             emit busy(message, numberOfOperations);
         }
         else {
-            emit busyProgressChanged(1);
+            emit busyProgressChanged(numberOfOperations);
         }
 
         emit busyChanged(isBusy);
