@@ -151,7 +151,8 @@ void UrlGrabber::parseYouTubeVideoPage() {
 
 void UrlGrabber::getDailymotionVideoUrl(const QString &id) {
     this->setBusy(true, tr("Loading video"));
-    QUrl url("http://www.dailymotion.com/video/" + id);
+    //QUrl url("http://www.dailymotion.com/video/" + id);
+    QUrl url("http://www.dailymotion.com/embed/video/" + id);
     QNetworkRequest request(url);
     QNetworkReply *reply;
 
@@ -173,7 +174,7 @@ void UrlGrabber::parseDailymotionVideoPage() {
         return;
     }
 
-    QString response(QByteArray::fromPercentEncoding(reply->readAll()).replace("\\", ""));
+    /*QString response(QByteArray::fromPercentEncoding(reply->readAll()).replace("\\", ""));
     QString manifestUrl = response.section("autoURL\":\"", 1, 1).section('"', 0, 0);
 
     if (manifestUrl.startsWith("http://")) {
@@ -183,6 +184,18 @@ void UrlGrabber::parseDailymotionVideoPage() {
         qDebug() << reply->request().url();
         qDebug() << response;
         emit error(tr("Unable to retrieve video. Access may be restricted"));
+    }*/
+    
+    QString response(reply->readAll());
+    QVariantMap info = Json::parse(response.section("var info = ", 1, 1).section(";\n", 0, 0)).toMap();
+    QUrl url(info.value("stream_h264_url").toString());
+    
+    if (url.isValid()) {
+        emit gotVideoUrl(url);
+    }
+    else {
+        qDebug() << response;
+        emit error(tr("Unable to retrieve video. Access may be restricted"));
     }
 
     reply->deleteLater();
